import Web_Component             from '../../core/Web_Component.mjs'
import Layout                    from '../../css/grid/Layout.mjs'
import CSS__Alerts              from "../../css/CSS__Alerts.mjs"
import CSS__Grid                from '../../css/grid/CSS__Grid.mjs'
import CSS__Typography          from '../../css/CSS__Typography.mjs'
import CSS__Side_Menu           from "../../css/menus/CSS__Side_Menu.mjs"
import Left_Menu                from "../../css/menus/Left_Menu.mjs"
import CBR__Left_Footer         from "../elements/CBR__Left_Footer.mjs"
import CBR__Top_Banner          from "../elements/CBR__Top_Banner.mjs"
import CBR__Left_Logo           from "../elements/CBR__Left_Logo.mjs"
import CBR__Important_Alert     from "../elements/CBR__Important_Alert.mjs"
import CBR__Content__Placeholder from "../elements/CBR__Content__Placeholder.mjs"

export default class WebC__CBR__Layout__Default extends Web_Component {
    constructor() {
        super()
        this.setupRouteHandler()
    }

    setupRouteHandler() {
        // Listen for popstate events (browser back/forward)
        window.addEventListener('popstate', (event) => {
            this.handleRoute(window.location.pathname)
        })

        // Intercept navigation clicks
        document.addEventListener('click', (event) => {
            const path = event.composedPath();
            const link = path.find(el => el.tagName === 'A');

            if (link && link.href.startsWith(window.location.origin)) {
                event.preventDefault()
                const path = link.href.replace(window.location.origin, '')
                this.navigate(path)
            }
        })
    }

    navigate(path) {
        window.history.pushState({}, '', path)
        this.handleRoute(path)
    }

    async handleRoute(path) {
        console.log('Handling route:', path)
        const contentEl = this.shadowRoot.querySelector('#content')
        window._this = this
        console.log(contentEl)
        if (!contentEl) return

        const placeholder = contentEl.querySelector('.placeholder-container')
        if (!placeholder) return

        // Extract the relevant part of the path after cbr-webc-dev
        const basePath = '/webc/cbr-webc'
        const routePath = path.replace(basePath, '').replace(/^\/+/, '') || 'home'

        // Show loading state
        placeholder.innerHTML = '<div class="content-loader">Loading...</div>'

        try {
            const content = await this.loadRouteContent(routePath)
            placeholder.innerHTML = ''
            placeholder.appendChild(content)
        } catch (error) {
            console.error('Error loading content:', error)
            placeholder.innerHTML = '<div class="content-error">Error loading content. Please try again.</div>'
        }
    }

    async loadRouteContent(routePath) {
        // This would be where you implement the actual content loading logic
        // For now, returning placeholder content
        const contentDiv = document.createElement('div')
        contentDiv.className = 'route-content'

        switch(routePath.toLowerCase()) {
            case 'home':
                contentDiv.innerHTML = '<h1>Welcome to The Cyber Boardroom</h1>'
                break
            case 'athena':
                contentDiv.innerHTML = '<h1>Athena Interface</h1>'
                break
            case 'personas':
                contentDiv.innerHTML = '<h1>Personas Management</h1>'
                break
            case 'past-chats':
            case 'pastchats':
                contentDiv.innerHTML = '<h1>Past Conversations</h1>'
                break
            case 'profile':
                contentDiv.innerHTML = '<h1>User Profile</h1>'
                break
            case 'chat':
                contentDiv.innerHTML = '<h1>Chat with LLMs</h1>'
                break
            case 'docs':
                contentDiv.innerHTML = '<h1>Documentation</h1>'
                break
            default:
                contentDiv.innerHTML = `<h1>Content for path: ${routePath}</h1>`
        }
        return contentDiv
    }

    load_attributes() {
        new CSS__Alerts              (this).apply_framework()
        new CSS__Grid                (this).apply_framework()
        new CSS__Typography          (this).apply_framework()
        new CSS__Side_Menu           (this).apply_framework()

        this.add_css_rules(CBR__Top_Banner          .css_rules())
        this.add_css_rules(CBR__Left_Footer         .css_rules())
        this.add_css_rules(CBR__Left_Logo           .css_rules())
        this.add_css_rules(CBR__Important_Alert     .css_rules())
        this.add_css_rules(CBR__Content__Placeholder.css_rules())

        // Add new CSS rules for routing functionality
        this.add_css_rules({
            ".content-loader": {
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center',
                height: '100%',
                fontSize: '1.2em',
                color: '#666'
            },
            ".content-error": {
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center',
                height: '100%',
                color: '#ff0000',
                fontSize: '1.2em'
            },
            ".route-content": {
                padding: '20px'
            }
        })
    }

    render() {
        let layout, row_banner, row_content

        layout      = new Layout({ id:'main-page', class: 'h-100vh p-0' })
        row_banner  = layout.add_row()
        row_content = layout.add_row({class: 'flex-fill flex-nowrap'                           })

        row_banner .add_col({ id: 'top-banner' , class: 'h-50px'                               })
        row_content.add_col({                    class: 'w-250px flex-column d-flex'           })
                   .add_col({ id: 'left-menu'  , class: 'flex-fill bg-white'                   }).parent()
                   .add_col({ id: 'left-footer', class: 'h-75px bg-light-gray'                 })
        row_content.add_col({ id: 'content'    , class: 'flex-fill bg-light-gray'          })

        layout.with_id('left-menu').add_tag({ tag: 'webc-api-side-menu' })

        // Define menu structure
        let menu_items = [{ icon: 'home'    , label: 'Home'           , href: '/webc/cbr-webc'                },
                         { icon: 'robot'    , label: 'Athena'         , href: '/webc/cbr-webc/athena' },
                         { icon: 'person'   , label: 'Personas'       , href: '/webc/cbr-webc/personas'     },
                         { icon: 'history'  , label: 'Past Chats'     , href: '/webc/cbr-webc/past-chats'   },
                         { icon: 'profile'  , label: 'Profile'        , href: '/webc/cbr-webc/profile'      },
                         { icon: 'chat'     , label: 'Chat with LLMs' , href: '/webc/cbr-webc/chat'         },
                         { icon: 'docs'     , label: 'Docs'           , href: '/webc/cbr-webc/docs'         }]
        let username = 'guest'

        layout     .with_id('left-menu'  ).add_element(new CBR__Left_Logo  ()                           )
        layout     .with_id('left-menu'  ).add_element(new Left_Menu       ({ menu_items: menu_items  }))
        layout     .with_id('left-menu'  ).add_element(new CBR__Important_Alert()                       )
        layout     .with_id('top-banner' ).add_element(new CBR__Top_Banner ({ username  : username    }))
        layout     .with_id('left-footer').add_element(new CBR__Left_Footer()                           )
        layout     .with_id('content'    ).add_element(new CBR__Content__Placeholder()                  )

        this.set_inner_html(layout.html())

        // Handle initial route
        this.handleRoute(window.location.pathname)
    }
}

WebC__CBR__Layout__Default.define()